SeoCheck extension type

The identity of a check, e.g. title.missing.

An extension type over String, matching the SeoTextTag idiom already in the package: the ids autocomplete and a typo is a compile error, but they stay plain strings in JSON output and in a --ignore= list.

on
Implemented types
Available extensions

Constructors

SeoCheck(String id)
const

Properties

characters Characters

Available on String, provided by the StringCharacters extension

The Characters of this string.
no setter
codeUnits List<int>
An unmodifiable list of the UTF-16 code units of this string.
no setterinherited
hashCode int
A hash code derived from the code units of the string.
no setterinherited
id String
final
isEmpty bool
Whether this string is empty.
no setterinherited
isNotEmpty bool
Whether this string is not empty.
no setterinherited
length int
The length of the string.
no setterinherited
runes Runes
An Iterable of Unicode code-points of this string.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toJS JSString

Available on String, provided by the StringToJSString extension

Converts this String to a JSString.
no setter

Methods

allMatches(String string, [int start = 0]) Iterable<Match>
Matches this pattern against the string repeatedly.
inherited
codeUnitAt(int index) int
Returns the 16-bit UTF-16 code unit at the given index.
inherited
compareTo(String other) int
Compares this string to other.
inherited
contains(Pattern other, [int startIndex = 0]) bool
Whether this string contains a match of other.
inherited
endsWith(String other) bool
Whether this string ends with other.
inherited
indexOf(Pattern pattern, [int start = 0]) int
Returns the position of the first match of pattern in this string, starting at start, inclusive:
inherited
lastIndexOf(Pattern pattern, [int? start]) int
The starting position of the last match pattern in this string.
inherited
matchAsPrefix(String string, [int start = 0]) Match?
Matches this pattern against the start of string.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padLeft(int width, [String padding = ' ']) String
Pads this string on the left if it is shorter than width.
inherited
padRight(int width, [String padding = ' ']) String
Pads this string on the right if it is shorter than width.
inherited
replaceAll(Pattern from, String replace) String
Replaces all substrings that match from with replace.
inherited
replaceAllMapped(Pattern from, String replace(Match match)) String
Replace all substrings that match from by a computed string.
inherited
replaceFirst(Pattern from, String to, [int startIndex = 0]) String
Creates a new string with the first occurrence of from replaced by to.
inherited
replaceFirstMapped(Pattern from, String replace(Match match), [int startIndex = 0]) String
Replace the first occurrence of from in this string.
inherited
replaceRange(int start, int? end, String replacement) String
Replaces the substring from start to end with replacement.
inherited
split(Pattern pattern) List<String>
Splits the string at matches of pattern and returns a list of substrings.
inherited
splitMapJoin(Pattern pattern, {String onMatch(Match)?, String onNonMatch(String)?}) String
Splits the string, converts its parts, and combines them into a new string.
inherited
startsWith(Pattern pattern, [int index = 0]) bool
Whether this string starts with a match of pattern.
inherited
substring(int start, [int? end]) String
The substring of this string from start, inclusive, to end, exclusive.
inherited
toLowerCase() String
Converts all characters in this string to lower case.
inherited
toString() String
A string representation of this object.
inherited
toUpperCase() String
Converts all characters in this string to upper case.
inherited
trim() String
The string without any leading and trailing whitespace.
inherited
trimLeft() String
The string without any leading whitespace.
inherited
trimRight() String
The string without any trailing whitespace.
inherited

Operators

operator *(int times) String
Creates a new string by concatenating this string with itself a number of times.
inherited
operator +(String other) String
Creates a new string by concatenating this string with other.
inherited
operator ==(Object other) bool
Whether other is a String with the same sequence of code units.
inherited
operator [](int index) String
The character (as a single-code-unit String) at the given index.
inherited

Constants

bodyEmpty → const SeoCheck
bodyTruncated → const SeoCheck
canonicalChain → const SeoCheck
canonicalNonIndexable → const SeoCheck
canonicalRelative → const SeoCheck
canonicalUnknownPath → const SeoCheck
descriptionDuplicate → const SeoCheck
descriptionLength → const SeoCheck
descriptionMissing → const SeoCheck
headingMultipleH1 → const SeoCheck
headingNoH1 → const SeoCheck
hreflangDuplicateTarget → const SeoCheck
hreflangInvalidCode → const SeoCheck
hreflangMissingSelf → const SeoCheck
hreflangNotReciprocal → const SeoCheck
hreflangRelative → const SeoCheck
hreflangUnknownTarget → const SeoCheck
imageAltMissing → const SeoCheck
imageSrcMissing → const SeoCheck
linkBroken → const SeoCheck
linkEmptyHref → const SeoCheck
linkNoText → const SeoCheck
linkToError → const SeoCheck
parityAppOnlyHeading → const SeoCheck
parityH1Differs → const SeoCheck
parityLinkMissingInApp → const SeoCheck
parityNotCovered → const SeoCheck
paritySsrOnlyText → const SeoCheck
resolverFailed → const SeoCheck
robotsNoindexInSitemap → const SeoCheck
routeDuplicatePath → const SeoCheck
routeNotEnumerated → const SeoCheck
routeShadowed → const SeoCheck
schemaInvalidJson → const SeoCheck
schemaMissingRecommended → const SeoCheck
schemaMissingRequired → const SeoCheck
schemaRelativeUrl → const SeoCheck
sitemapEmpty → const SeoCheck
titleDuplicate → const SeoCheck
titleLength → const SeoCheck
titleMissing → const SeoCheck
urlRejectedByPolicy → const SeoCheck