message property
One sentence saying what is wrong, in terms of the author's own route table rather than of the audit's internals.
Implementation
final String message;
One sentence saying what is wrong, in terms of the author's own route table rather than of the audit's internals.
final String message;