enableInteractions property

bool enableInteractions
final

Whether to include the trusted package interaction runtime.

The runtime only enhances components that explicitly opt in and ignores content below an inert or aria-hidden="true" ancestor.

Implementation

final bool enableInteractions;