SeoDomFirstRuntimeArtifact class final
JavaScript that passed manifest, identity, size, and content verification.
Constructors
- SeoDomFirstRuntimeArtifact.create({required SeoDomFirstApplicationRuntime reference, required String javascript, required String dartVersion})
-
Creates and verifies an artifact from compiler output.
factory
- SeoDomFirstRuntimeArtifact.verify({required SeoDomFirstApplicationRuntime reference, required SeoDomFirstRuntimeManifest manifest, required String javascript})
-
Verifies identity and file consistency for a build-owned artifact.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- javascript → String
-
final
- manifest → SeoDomFirstRuntimeManifest
-
final
- reference → SeoDomFirstApplicationRuntime
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited