SeoDomFirstRuntimeManifest class final
Describes one compiled and content-addressed application runtime.
Constructors
- SeoDomFirstRuntimeManifest({required int schemaVersion, required String id, required String kind, required String dartVersion, required String sha256, required int bytes, required int gzipBytes})
-
const
- SeoDomFirstRuntimeManifest.fromJson(Object? value)
-
factory
Properties
- bytes → int
-
final
- dartVersion → String
-
final
- gzipBytes → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- kind → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → int
-
final
- sha256 → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited