seoDomFirstRuntimeMaxBytes top-level constant
int
const seoDomFirstRuntimeMaxBytes
Maximum accepted application runtime size before compression.
The separate ceiling bounds file reads, hashing, compression and browser parse work even when highly repetitive JavaScript compresses unusually well.
Implementation
const int seoDomFirstRuntimeMaxBytes = 512 * 1024;